@@ -6,7 +6,7 @@ Mojolicious::Plugin::LinkEmbedder - Convert a URL to embedded content
 
 =head1 VERSION
 
-0.20
+0.21
 
 =head1 DESCRIPTION
 
@@ -103,6 +103,8 @@ Caching is EXPERIMENTAL and could be removed without notice.
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video>
 
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify>
+
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn>
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv>
@@ -127,8 +129,14 @@ Caching is EXPERIMENTAL and could be removed without notice.
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub>
 
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix>
+
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan>
 
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastebin>
+
+=item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::PasteScsysCoUk>
+
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter>
 
 =item * L<Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis>
@@ -144,7 +152,7 @@ use Mojo::UserAgent;
 use Mojolicious::Plugin::LinkEmbedder::Link;
 use constant DEBUG => $ENV{MOJO_LINKEMBEDDER_DEBUG} || 0;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 has _ua => sub { Mojo::UserAgent->new(max_redirects => 3) };
 
@@ -167,6 +175,9 @@ sub embed_link {
   if ($url =~ m!\.(?:mpg|mpeg|mov|mp4|ogv)\b!i) {
     return $c if $self->_new_link_object(video => $c, {url => $url}, $cb);
   }
+  if ($url =~ m!^spotify:!i) {
+    return $c if $self->_new_link_object('open.spotify' => $c, {url => $url}, $cb);
+  }
 
   return $c->delay(
     sub {
@@ -185,20 +196,21 @@ sub _learn {
   my $ct = $tx->res->headers->content_type || '';
   my $url = $tx->req->url;
 
-  return if $ct =~ m!^image/!     and $self->_new_link_object(image => $c, {url => $url, _tx => $tx}, $cb);
-  return if $ct =~ m!^video/!     and $self->_new_link_object(video => $c, {url => $url, _tx => $tx}, $cb);
-  return if $ct =~ m!^text/plain! and $self->_new_link_object(text  => $c, {url => $url, _tx => $tx}, $cb);
-
   if (my $type = lc $url->host) {
     $type =~ s/^(?:www|my)\.//;
     $type =~ s/\.\w+$//;
     return if $self->_new_link_object($type => $c, {_tx => $tx}, $cb);
   }
+
+  return if $ct =~ m!^image/!     and $self->_new_link_object(image => $c, {url => $url, _tx => $tx}, $cb);
+  return if $ct =~ m!^video/!     and $self->_new_link_object(video => $c, {url => $url, _tx => $tx}, $cb);
+  return if $ct =~ m!^text/plain! and $self->_new_link_object(text  => $c, {url => $url, _tx => $tx}, $cb);
+
   if ($ct =~ m!^text/html!) {
     return if $self->_new_link_object(html => $c, {_tx => $tx}, $cb);
   }
 
-  warn "[LINK] New from $ct: Mojolicious::Plugin::LinkEmbedder::Link\n" if DEBUG;
+  warn "[LINK] New from $ct: Mojolicious::Plugin::LinkEmbedder::Link ($url)\n" if DEBUG;
   $c->$cb(Mojolicious::Plugin::LinkEmbedder::Link->new(_tx => $tx));
 }
 
@@ -250,26 +262,30 @@ sub register {
   my ($self, $app, $config) = @_;
 
   $self->{classes} = {
-    'appear'       => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn',
-    '2play'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
-    'beta.dbtv'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
-    'dbtv'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
-    'blip'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip',
-    'collegehumor' => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor',
-    'gist.github'  => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
-    'github'       => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Github',
-    'html'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML',
-    'image'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
-    'imgur'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
-    'metacpan'     => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan',
-    'ted'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted',
-    'text'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text',
-    'twitter'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter',
-    'travis-ci'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis',
-    'video'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video',
-    'vimeo'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo',
-    'youtube'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube',
-    'xkcd'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Xkcd',
+    'appear'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::AppearIn',
+    '2play'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Game::_2play',
+    'beta.dbtv'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
+    'dbtv'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Dbtv',
+    'blip'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Blip',
+    'collegehumor'   => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Collegehumor',
+    'gist.github'    => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::GistGithub',
+    'github'         => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Github',
+    'html'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::HTML',
+    'image'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image',
+    'imgur'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Imgur',
+    'ix'             => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Ix',
+    'metacpan'       => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Metacpan',
+    'open.spotify'   => 'Mojolicious::Plugin::LinkEmbedder::Link::Music::Spotify',
+    'paste.scsys.co' => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::PasteScsysCoUk',
+    'pastebin'       => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Pastebin',
+    'ted'            => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Ted',
+    'text'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Text',
+    'twitter'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Twitter',
+    'travis-ci'      => 'Mojolicious::Plugin::LinkEmbedder::Link::Text::Travis',
+    'video'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Video',
+    'vimeo'          => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Vimeo',
+    'youtube'        => 'Mojolicious::Plugin::LinkEmbedder::Link::Video::Youtube',
+    'xkcd'           => 'Mojolicious::Plugin::LinkEmbedder::Link::Image::Xkcd',
   };
 
   $app->helper(
