@@ -41,14 +41,9 @@ sub provider_name {'Vimeo'}
 sub learn {
   my ($self, $c, $cb) = @_;
 
-  if ($self->media_id) {
-    $self->$cb;
-  }
-  else {
-    $self->SUPER::learn($c, $cb);
-  }
-
-  return $self;
+  return $self->SUPER::learn($c, $cb) unless $self->media_id;
+  $self->$cb;
+  $self;
 }
 
 =head2 to_embed
@@ -63,10 +58,12 @@ sub to_embed {
   my $src      = Mojo::URL->new('//player.vimeo.com/video/86404451?portrait=0&amp;color=ffffff');
   my %args     = @_;
 
-  $args{height} ||= 281;
-  $args{width}  ||= 500;
-
-  qq(<iframe src="//player.vimeo.com/video/$media_id?portrait=0&amp;color=ffffff" width="$args{width}" height="$args{height}" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>);
+  $self->_iframe(
+    src    => "//player.vimeo.com/video/$media_id?portrait=0&color=ffffff",
+    class  => 'link-embedder video-vimeo',
+    width  => $args{width} || 500,
+    height => $args{height} || 281
+  );
 }
 
 =head1 AUTHOR
